==> simulatorAPMS_1.14.0.tar.gz: simulatorAPMS/man/applyDeformationError.Rd <==
\name{applyDeformationError}
\alias{applyDeformationError}
\title{Function that handles deformed bait proteins}
\description{
  This function simulates False Negative (FN) observations on
  those bait proteins known to have been deformed during the
  AP-MS process. 
}
\usage{
applyDeformationError(foundPrey, rateDeform)
}

\arguments{
  \item{foundPrey}{A character vector of proteins names that interact
    with the a particular deformed protein P}
  \item{rateDeform}{The rate at which the deformation in P produces
    false negative observations within the AP-MS technology}
}
\details{
  If there is a non-trivial number of deformed bait proteins, the
  function \code{\link{runSimulators}} calls the intermediary function
  \code{\link{simulatorD}}. This latter function controls
  \code{\link{applyDeformationError}} by examining the arguments and
  parameters. For each deformed bait, \code{\link{simulatorD}} calls
  this function to generate deformation errors.
  
  This is essentially a function for recording more FN interactions
  among baits and prey. The function takes in a bait that is known to
  have some deformation as a result of the experimentation.

  In essence, the bait loses some capacity to pull other proteins with
  which it would normally interact.

}
\value{

  The character vector, missedPrey:

  The return value missedPrey is a vector which is a subset of the
  vector foundPrey. This subset will be the proteins which will be
  included as FN observations due to the systematic errors via the
  deformation of protein P.
}

\author{T. Chiang}

\seealso{ \code{\link{applyFNErrors}, \code{\link{runSimulators}}}}
\examples{
data(TSNMatrix)
exampleFoundPrey <- rownames(TSNMatrix)[1:50]
applyDeformationError(exampleFoundPrey, 0.5)
}

\keyword{datagen}

==> simulatorAPMS_1.22.0.tar.gz: simulatorAPMS/man/applyDeformationError.Rd <==
\name{applyDeformationError}
\alias{applyDeformationError}
\title{Function that handles deformed bait proteins}
\description{
  This function simulates False Negative (FN) observations on
  those bait proteins known to have been deformed during the
  AP-MS process. 
}
\usage{
applyDeformationError(foundPrey, rateDeform)
}

\arguments{
  \item{foundPrey}{A character vector of proteins names that interact
    with the a particular deformed protein P}
  \item{rateDeform}{The rate at which the deformation in P produces
    false negative observations within the AP-MS technology}
}
\details{
  If there is a non-trivial number of deformed bait proteins, the
  function \code{\link{runSimulators}} calls the intermediary function
  \code{\link{simulatorD}}. This latter function controls
  \code{\link{applyDeformationError}} by examining the arguments and
  parameters. For each deformed bait, \code{\link{simulatorD}} calls
  this function to generate deformation errors.
  
  This is essentially a function for recording more FN interactions
  among baits and prey. The function takes in a bait that is known to
  have some deformation as a result of the experimentation.

  In essence, the bait loses some capacity to pull other proteins with
  which it would normally interact.

}
\value{

  The character vector, missedPrey:

  The return value missedPrey is a vector which is a subset of the
  vector foundPrey. This subset will be the proteins which will be
  included as FN observations due to the systematic errors via the
  deformation of protein P.
}

\author{T. Chiang}

\seealso{ \code{\link{applyFNErrors}}, \code{\link{runSimulators}}}
\examples{
data(TSNMatrix)
exampleFoundPrey <- rownames(TSNMatrix)[1:50]
applyDeformationError(exampleFoundPrey, 0.5)
}

\keyword{datagen}
